@@ -5,14 +5,14 @@ package Mail::Builder;
 use namespace::autoclean;
 use Moose;
 
-our $VERSION = "2.09";
+our $VERSION = "2.10";
 our $AUTHORITY = 'cpan:MAROS';
 
 use Mail::Builder::TypeConstraints;
+use Mail::Builder::Utils;
 
 use Carp;
 
-use Encode qw(encode decode); 
 use MIME::Entity;
 
 use Email::MessageID;
@@ -349,7 +349,7 @@ sub _build_text {
         && $self->has_plaintext) {
         
         # Build multipart/alternative envelope for HTML and plaintext
-        $mime_part = build MIME::Entity(
+        $mime_part = MIME::Entity->build(
             %mime_params,
             Type        => q[multipart/alternative],
             Boundary    => $self->_get_boundary(),
@@ -357,7 +357,7 @@ sub _build_text {
         );
         
         # Add the plaintext entity first
-        $mime_part->add_part(build MIME::Entity (
+        $mime_part->add_part(MIME::Entity->build(
             Top         => 0,
             Type        => qq[text/plain; charset="utf-8"],
             Data        => $self->plaintext,
@@ -368,7 +368,7 @@ sub _build_text {
         $mime_part->add_part($self->_build_html(Top => 0));
     # We only have plaintext
     } else {
-        $mime_part = build MIME::Entity (
+        $mime_part = MIME::Entity->build(
             %mime_params,
             Type        => qq[text/plain; charset="utf-8"],
             Data        => $self->plaintext,
@@ -387,14 +387,14 @@ sub _build_html {
     # We have inline images
     if ($self->image->length) {
         # So we need a multipart/related envelope first
-        $mime_part = build MIME::Entity(
+        $mime_part = MIME::Entity->build(
             %mime_params,
             Type        => q[multipart/related],
             Boundary    => $self->_get_boundary(),
             Encoding    => 'binary',
         );
         # Add the html body
-        $mime_part->add_part(build MIME::Entity (
+        $mime_part->add_part(MIME::Entity->build(
             Top         => 0,
             Type        => qq[text/html; charset="utf-8"],
             Data        => $self->htmltext,
@@ -406,7 +406,7 @@ sub _build_html {
         }
     # We don't have any inline images
     } else {
-        $mime_part = build MIME::Entity (
+        $mime_part = MIME::Entity->build(
             %mime_params,
             Type        => qq[text/html; charset="utf-8"],
             Data        => $self->htmltext,
@@ -446,10 +446,10 @@ sub build_message {
         'Cc'            => $self->cc->join(','),
         'Bcc'           => $self->bcc->join(','),
         'Date'          => $self->date,
-        'Subject'       => encode('MIME-Header',$self->subject),
+        'Subject'       => Mail::Builder::Utils::encode_mime($self->subject),
         'Message-ID'    => $messageid->in_brackets(),
         'X-Priority'    => $self->priority,
-        'X-Mailer'      => encode('MIME-Header', $self->mailer),
+        'X-Mailer'      => Mail::Builder::Utils::encode_mime($self->mailer),
     );
     
     # Set reply address
@@ -478,7 +478,7 @@ sub build_message {
     
     # Set organizsation
     if ($self->has_organization) {
-        $email_header{'Organization'} = encode('MIME-Header', $self->organization);
+        $email_header{'Organization'} = Mail::Builder::Utils::encode_mime($self->organization);
     }
     
     # Build e-mail entity ...
@@ -486,7 +486,7 @@ sub build_message {
     
     # ... with attachments
     if ($self->attachment->length()) {
-        $mime_entity = build MIME::Entity(
+        $mime_entity = MIME::Entity->build(
             %email_header,
             Type        => 'multipart/mixed',
             Boundary    => $self->_get_boundary(),
@@ -590,7 +590,7 @@ attachment lists and image lists)
 
 =head3 new
 
-This is a simple constructor. It accepts all defined acccessors as a Hash orr 
+This is a simple constructor. It accepts all defined acccessors as a Hash or 
 HashRef.
 
 =head2 Public methods 
@@ -626,7 +626,7 @@ Each call to this method also changes the C<messageid>.
 =head3 purge_cache
 
 Emptys the attachment and image cache and removes the plaintext text if it has
-been autogenerated from html text. Also resets the Message ID nd date header.
+been autogenerated from html text. Also resets the Message ID and date header.
 
 =head2 Accessors 
 
@@ -745,8 +745,8 @@ methods can be used to check respectively clear the value.
 =head3 messageid
 
 Message ID of the e-mail as a  L<Email::MessageID> object. Read only and 
-available only after the C<build_message> or C<stingify> methods have been 
-called. Each call to C<build_message> or C<stingify> changes the message ID.
+available only after the C<build_message> or C<stringify> methods have been 
+called. Each call to C<build_message> or C<stringify> changes the message ID.
 The C<has_messageid> and C<clear_messageid> methods can be used to check 
 respectively clear the value.
 
