@@ -7,7 +7,7 @@ use Moose;
 use Mail::Builder::TypeConstraints;
 
 use Carp;
-use Encode qw/encode decode/; 
+
 
 use Email::Valid;
 
@@ -146,8 +146,8 @@ sub serialize {
     my $name = $self->name;
     $name =~ s/"/\\"/g;
     
-    my $return = sprintf '"%s" <%s>',encode('MIME-Header', $name),$self->email;
-    $return .= ' '.$self->comment
+    my $return = sprintf '"%s" <%s>',Mail::Builder::Utils::encode_mime($name),$self->email;
+    $return .= ' '.Mail::Builder::Utils::encode_mime($self->comment)
         if $self->has_comment;
     
     return $return;
